pub enum FakeResultRemainderPolicy {
Drop,
Discard,
}Expand description
What to do with fake result output that cannot fit during a shift-click.
Variants
Drop
Drop the unresolved output into the world, as crafting menus do.
Discard
Discard the unresolved output after the result handler runs, as anvils do.