pub struct DataSlot {
menu: MenuInstanceId,
index: usize,
}Expand description
A data slot handle created by the MenuBuilder::data_slot, to use for easy access
instead of a bare index.
Fields
index: usizeImplementations
Sourceimpl DataSlot
impl DataSlot
Sourcepub fn get(self, behavior: &MenuBehavior) -> i16
pub fn get(self, behavior: &MenuBehavior) -> i16
Reads the current value of this data slot.
Panics
Panics if behavior belongs to a different menu than the
MenuBuilder that minted this handle.
Sourcepub fn set(self, behavior: &mut MenuBehavior, value: i16)
pub fn set(self, behavior: &mut MenuBehavior, value: i16)
Writes a new value to this data slot.
Panics
Panics if behavior belongs to a different menu than the
MenuBuilder that minted this handle.