Region

Struct Region 

pub struct Region {
    sections: Vec<Section>,
}
The sections created by a grid placement.

Fields

sections: Vec<Section>

Implementations

Source

impl Region

pub fn iter(&self) -> Copied<Iter<'_, Section>>

Iterates the sections of this region.

pub fn contains(&self, slot_index: usize) -> bool

Whether any section of this region contains the slot index.

pub fn single(&self) -> Section

The region’s only section.

Panics

If the region is not one contiguous slot range.